Enum TryRecvError
pub enum TryRecvError {
Empty,
Disconnected,
}Expand description
Error returned by Receiver::try_recv.
Variants
Empty
This channel is currently empty, but the Sender(s) have not yet disconnected, so data may yet become available.
Disconnected
The channel’s sending half has become disconnected, and there will never be any more data received on it.